@@ -24,6 +24,10 @@
     \file avi.cc
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "riff.h"
 #include "avi.h"
 #include <stdio.h>
@@ -492,7 +496,8 @@ void AVI1File::WriteRIFF()
         WriteChunk(strf1_chunk, (void*)&dvinfo);
         WriteChunk(indx_chunk, (void*)&indx);
         WriteChunk(dmlh_chunk, (void*)&dmlh);
-        WriteChunk(ix00_chunk, (void*)&ix00);
+        if (ix00_chunk != -1)
+		WriteChunk(ix00_chunk, (void*)&ix00);
 
         RIFFFile::WriteRIFF();
 }
@@ -661,7 +666,7 @@ void AVI2File::Init(int format, int sampleFrequency)
         waveformatex.nBlockAlign = 4;
         waveformatex.wBitsPerSample = 16;
 
-        for (int i = 0; i < 64000; ++i)
+        for (int i = 0; i < 80000; ++i)
                 idx1[i] = 0;
         idx1_entries = 0;
 
@@ -709,6 +714,8 @@ void AVI2File::WriteFrame(const Frame &frame)
 
         /* Write audio data if we have it */
 
+	assert(idx1_entries <= 80000 / 4 - 8); // quick and dirty; we have currently only space for 10000 frames
+
         if (audio_size > 0) {
                 audio_chunk = AddDirectoryEntry(make_fourcc("01wb"), 0, audio_size, movi_list);
                 stream2Hdr.dwLength += audio_size;
